@@ -6,7 +6,7 @@ knitr::opts_chunk$set(
 
 ## ----fig.width=4.5,fig.height=3------------------------------------------
 library(Spectrum)
-test1 <- Spectrum(blobs,showdimred=TRUE)
+test1 <- Spectrum(blobs,showdimred=TRUE,fontsize=8)
 
 ## ------------------------------------------------------------------------
 names(test1)
@@ -14,17 +14,17 @@ names(test1)
 ## ----fig.width=4.5,fig.height=3------------------------------------------
 library(Spectrum)
 RNAseq <- brain[[1]]
-test2 <- Spectrum(RNAseq,showdimred=TRUE)
+test2 <- Spectrum(RNAseq,showdimred=TRUE,fontsize=8)
 
 ## ----fig.width=4.5,fig.height=3------------------------------------------
 library(Spectrum)
-test3 <- Spectrum(brain,showdimred=TRUE)
+test3 <- Spectrum(brain,showdimred=TRUE,fontsize=8)
 
 ## ----fig.width=4.5,fig.height=3------------------------------------------
 library(Spectrum)
-test4 <- Spectrum(circles,showpca=TRUE,method=2)
+test4 <- Spectrum(circles,showpca=TRUE,method=2,fontsize=8)
 
 ## ----fig.width=4.5,fig.height=3------------------------------------------
 library(Spectrum)
-test5 <- Spectrum(spirals,showpca=TRUE,method=2)
+test5 <- Spectrum(spirals,showpca=TRUE,method=2,fontsize=8)
 
